# How to query PHOTONAI's result logging
 
There is a whole bunch of information stored in PHOTONAI's result logging tree. 
Here we showcase some convenience function to easily retrieve
useful result details. 


```python
{% include 'examples/results/results_example.py' %}
```